@@ -1,7 +1,7 @@
 use pretty_assertions::assert_eq;
 use reinfer_client::{
-    Dataset, EntityDef, EntityName, LabelDef, LabelDefPretrained, LabelDefPretrainedId, LabelName,
-    Source,
+    Dataset, EntityDef, EntityName, LabelDef, LabelDefPretrained, LabelDefPretrainedId, LabelGroup,
+    LabelGroupName, LabelName, Source,
 };
 use serde_json::json;
 use uuid::Uuid;
@@ -150,6 +150,7 @@ fn test_create_update_dataset_custom() {
         source_ids: Vec<String>,
         entity_defs: Vec<EntityDefInfo>,
         label_defs: Vec<LabelDef>,
+        label_groups: Vec<LabelGroup>,
     }
 
     impl From<Dataset> for DatasetInfo {
@@ -163,6 +164,7 @@ fn test_create_update_dataset_custom() {
                 source_ids: dataset.source_ids.into_iter().map(|id| id.0).collect(),
                 entity_defs: dataset.entity_defs.into_iter().map(Into::into).collect(),
                 label_defs: dataset.label_defs,
+                label_groups: dataset.label_groups,
             }
         }
     }
@@ -231,6 +233,28 @@ fn test_create_update_dataset_custom() {
                 title: "Title Me".to_owned(),
             },
         ],
+        label_groups: vec![LabelGroup {
+            name: LabelGroupName("default".to_owned()),
+            label_defs: vec![
+                LabelDef {
+                    name: LabelName("bar".to_owned()),
+                    description: "".to_owned(),
+                    external_id: None,
+                    pretrained: None,
+                    title: "".to_owned(),
+                },
+                LabelDef {
+                    name: LabelName("foo".to_owned()),
+                    description: "Long label description".to_owned(),
+                    external_id: Some("ext id".to_owned()),
+                    pretrained: Some(LabelDefPretrained {
+                        id: LabelDefPretrainedId("0000000000000001".to_owned()),
+                        name: LabelName("Autogenerated".to_owned()),
+                    }),
+                    title: "Title Me".to_owned(),
+                },
+            ],
+        }],
     };
     assert_eq!(get_dataset_info(), expected_dataset_info);
 
