@@ -119,6 +119,7 @@ fn test_create_update_source_custom() {
         description: String,
         language: String,
         should_translate: bool,
+        source_type: String,
     }
 
     impl From<Source> for SourceInfo {
@@ -130,6 +131,7 @@ fn test_create_update_source_custom() {
                 description: source.description,
                 language: source.language,
                 should_translate: source.should_translate,
+                source_type: source.source_type.to_string(),
             }
         }
     }
@@ -146,6 +148,7 @@ fn test_create_update_source_custom() {
         description: "some description".to_owned(),
         language: "de".to_owned(),
         should_translate: true,
+        source_type: "unknown".to_owned(),
     };
     assert_eq!(get_source_info(), expected_source_info);
 
@@ -178,6 +181,45 @@ fn test_create_update_source_custom() {
     assert_eq!(get_source_info(), expected_source_info);
 }
 
+#[test]
+fn test_create_source_with_type() {
+    let cli = TestCli::get();
+    let source = TestSource::new_args(&["--title=some title", "--source-type=call"]);
+
+    /// A subset of source fields that we can easily check for equality accross
+    #[derive(PartialEq, Eq, Debug)]
+    struct SourceInfo {
+        owner: String,
+        name: String,
+        title: String,
+        source_type: String,
+    }
+
+    impl From<Source> for SourceInfo {
+        fn from(source: Source) -> SourceInfo {
+            SourceInfo {
+                owner: source.owner.0,
+                name: source.name.0,
+                title: source.title,
+                source_type: source.source_type.to_string(),
+            }
+        }
+    }
+
+    let get_source_info = || -> SourceInfo {
+        let output = cli.run(&["--output=json", "get", "sources", source.identifier()]);
+        serde_json::from_str::<Source>(&output).unwrap().into()
+    };
+
+    let expected_source_info = SourceInfo {
+        owner: source.owner().to_owned(),
+        name: source.name().to_owned(),
+        title: "some title".to_owned(),
+        source_type: "call".to_owned(),
+    };
+    assert_eq!(get_source_info(), expected_source_info);
+}
+
 #[test]
 fn test_create_source_requires_owner() {
     let cli = TestCli::get();
